Struct rhizo_types::OnchainBytes
source · pub struct OnchainBytes {
pub inner: Vec<u8>,
}Expand description
Representation of OnchainBytes as exists on the Solana blockchain
Fields
inner: Vec<u8>Trait Implementations
sourceimpl BorshDeserialize for OnchainByteswhere
Vec<u8>: BorshDeserialize,
impl BorshDeserialize for OnchainByteswhere Vec<u8>: BorshDeserialize,
fn deserialize_reader<R: Read>(reader: &mut R) -> Result<Self, Error>
sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where R: Read,
sourceimpl BorshSerialize for OnchainByteswhere
Vec<u8>: BorshSerialize,
impl BorshSerialize for OnchainByteswhere Vec<u8>: BorshSerialize,
sourceimpl Clone for OnchainBytes
impl Clone for OnchainBytes
sourcefn clone(&self) -> OnchainBytes
fn clone(&self) -> OnchainBytes
Returns a copy of the value. Read more
1.0.0 · sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moresourceimpl Debug for OnchainBytes
impl Debug for OnchainBytes
sourceimpl<'de> Deserialize<'de> for OnchainBytes
impl<'de> Deserialize<'de> for OnchainBytes
sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where __D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
sourceimpl PartialEq for OnchainBytes
impl PartialEq for OnchainBytes
sourcefn eq(&self, other: &OnchainBytes) -> bool
fn eq(&self, other: &OnchainBytes) -> bool
This method tests for
self and other values to be equal, and is used
by ==.sourceimpl Serialize for OnchainBytes
impl Serialize for OnchainBytes
impl Eq for OnchainBytes
impl StructuralEq for OnchainBytes
impl StructuralPartialEq for OnchainBytes