Struct rhizo_types::RouteDeploy
source · pub struct RouteDeploy {
pub source: Vec<u8>,
pub metadata: RouteData,
}Expand description
Representation of route deploy data
Fields
source: Vec<u8>metadata: RouteDataTrait Implementations
sourceimpl BorshDeserialize for RouteDeploywhere
Vec<u8>: BorshDeserialize,
RouteData: BorshDeserialize,
impl BorshDeserialize for RouteDeploywhere Vec<u8>: BorshDeserialize, RouteData: BorshDeserialize,
fn deserialize_reader<R: Read>(reader: &mut R) -> Result<Self, Error>
sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where R: Read,
sourceimpl BorshSerialize for RouteDeploywhere
Vec<u8>: BorshSerialize,
RouteData: BorshSerialize,
impl BorshSerialize for RouteDeploywhere Vec<u8>: BorshSerialize, RouteData: BorshSerialize,
sourceimpl Clone for RouteDeploy
impl Clone for RouteDeploy
sourcefn clone(&self) -> RouteDeploy
fn clone(&self) -> RouteDeploy
Returns a copy of the value. Read more
1.0.0 · sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moresourceimpl Debug for RouteDeploy
impl Debug for RouteDeploy
sourceimpl<'de> Deserialize<'de> for RouteDeploy
impl<'de> Deserialize<'de> for RouteDeploy
sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where __D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
sourceimpl PartialEq for RouteDeploy
impl PartialEq for RouteDeploy
sourcefn eq(&self, other: &RouteDeploy) -> bool
fn eq(&self, other: &RouteDeploy) -> bool
This method tests for
self and other values to be equal, and is used
by ==.sourceimpl Serialize for RouteDeploy
impl Serialize for RouteDeploy
impl Eq for RouteDeploy
impl StructuralEq for RouteDeploy
impl StructuralPartialEq for RouteDeploy