Struct rhizo_types::RouteUpdate
source · pub struct RouteUpdate {
pub route: String,
pub bump_seed: Option<u8>,
pub operation: u8,
}Expand description
Representation of RouteData as exists on the Solana blockchain
Fields
route: Stringbump_seed: Option<u8>operation: u8Trait Implementations
sourceimpl BorshDeserialize for RouteUpdatewhere
String: BorshDeserialize,
Option<u8>: BorshDeserialize,
u8: BorshDeserialize,
impl BorshDeserialize for RouteUpdatewhere String: BorshDeserialize, Option<u8>: BorshDeserialize, u8: BorshDeserialize,
fn deserialize_reader<R: Read>(reader: &mut R) -> Result<Self, Error>
sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where R: Read,
sourceimpl BorshSerialize for RouteUpdatewhere
String: BorshSerialize,
Option<u8>: BorshSerialize,
u8: BorshSerialize,
impl BorshSerialize for RouteUpdatewhere String: BorshSerialize, Option<u8>: BorshSerialize, u8: BorshSerialize,
sourceimpl Clone for RouteUpdate
impl Clone for RouteUpdate
sourcefn clone(&self) -> RouteUpdate
fn clone(&self) -> RouteUpdate
Returns a copy of the value. Read more
1.0.0 · sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moresourceimpl Debug for RouteUpdate
impl Debug for RouteUpdate
sourceimpl<'de> Deserialize<'de> for RouteUpdate
impl<'de> Deserialize<'de> for RouteUpdate
sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where __D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
sourceimpl PartialEq for RouteUpdate
impl PartialEq for RouteUpdate
sourcefn eq(&self, other: &RouteUpdate) -> bool
fn eq(&self, other: &RouteUpdate) -> bool
This method tests for
self and other values to be equal, and is used
by ==.sourceimpl Serialize for RouteUpdate
impl Serialize for RouteUpdate
impl Eq for RouteUpdate
impl StructuralEq for RouteUpdate
impl StructuralPartialEq for RouteUpdate