Struct rhizo_types::SignedOnchainBytes
source · pub struct SignedOnchainBytes {
pub inner: Vec<u8>,
pub owner_pubkey: [u8; 32],
}Expand description
Representation of OnchainBytes as exists on the Solana blockchain
Fields
inner: Vec<u8>owner_pubkey: [u8; 32]Trait Implementations
sourceimpl BorshDeserialize for SignedOnchainByteswhere
Vec<u8>: BorshDeserialize,
[u8; 32]: BorshDeserialize,
impl BorshDeserialize for SignedOnchainByteswhere Vec<u8>: BorshDeserialize, [u8; 32]: BorshDeserialize,
fn deserialize_reader<R: Read>(reader: &mut R) -> Result<Self, Error>
sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where R: Read,
sourceimpl BorshSerialize for SignedOnchainByteswhere
Vec<u8>: BorshSerialize,
[u8; 32]: BorshSerialize,
impl BorshSerialize for SignedOnchainByteswhere Vec<u8>: BorshSerialize, [u8; 32]: BorshSerialize,
sourceimpl Clone for SignedOnchainBytes
impl Clone for SignedOnchainBytes
sourcefn clone(&self) -> SignedOnchainBytes
fn clone(&self) -> SignedOnchainBytes
Returns a copy of the value. Read more
1.0.0 · sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moresourceimpl Debug for SignedOnchainBytes
impl Debug for SignedOnchainBytes
sourceimpl<'de> Deserialize<'de> for SignedOnchainBytes
impl<'de> Deserialize<'de> for SignedOnchainBytes
sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where __D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
sourceimpl PartialEq for SignedOnchainBytes
impl PartialEq for SignedOnchainBytes
sourcefn eq(&self, other: &SignedOnchainBytes) -> bool
fn eq(&self, other: &SignedOnchainBytes) -> bool
This method tests for
self and other values to be equal, and is used
by ==.sourceimpl Serialize for SignedOnchainBytes
impl Serialize for SignedOnchainBytes
impl Eq for SignedOnchainBytes
impl StructuralEq for SignedOnchainBytes
impl StructuralPartialEq for SignedOnchainBytes