pub struct UserPDAResources {
pub seeds: Vec<String>,
}Expand description
Representation of a list of User owned resources, backed by on-chain PDAs
Fields
seeds: Vec<String>Trait Implementations
Sourceimpl BorshDeserialize for UserPDAResources
impl BorshDeserialize for UserPDAResources
fn deserialize_reader<R: Read>(reader: &mut R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl BorshSerialize for UserPDAResources
impl BorshSerialize for UserPDAResources
Sourceimpl Clone for UserPDAResources
impl Clone for UserPDAResources
Sourcefn clone(&self) -> UserPDAResources
fn clone(&self) -> UserPDAResources
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for UserPDAResources
impl Debug for UserPDAResources
Sourceimpl<'de> Deserialize<'de> for UserPDAResources
impl<'de> Deserialize<'de> for UserPDAResources
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl PartialEq for UserPDAResources
impl PartialEq for UserPDAResources
Sourceimpl Serialize for UserPDAResources
impl Serialize for UserPDAResources
impl Eq for UserPDAResources
impl StructuralPartialEq for UserPDAResources